@@ -1,5 +1,7 @@
-from abc import ABC, abstractmethod
-from typing import Generic, TypeVar
+from abc import ABC
+from abc import abstractmethod
+from typing import Generic
+from typing import TypeVar
 
 T = TypeVar("T")
 
@@ -18,4 +20,4 @@ class Factory(ABC, Generic[T]):
 
     def destroy(self, item: T) -> None:
         """Release resources managed by the `T` object"""
-        return True
+        return
